API documentation
=================

The following documentation is based on the source code of version |release| of
the `verboselogs` package.

:mod:`verboselogs`
------------------

.. automodule:: verboselogs
   :members:

:mod:`verboselogs.pylint`
-------------------------

.. automodule:: verboselogs.pylint
   :members:
